@@ -26,6 +26,14 @@ Binder::Binder() :
 BayonneBinder("troll")
 {
         static ScriptInterp::Define interp[] = {
+		{"dial", false, (Method)&Methods::scrConnect,
+			(Check)&Checks::chkConnect},
+                {"connect", false, (Method)&Methods::scrConnect,
+                        (Check)&Checks::chkConnect},   
+		{"timeslot", false, (Method)&ScriptMethods::scrNop,
+			(Check)&Checks::chkTrunking},
+		{"span", false, (Method)&ScriptMethods::scrNop,
+			(Check)&Checks::chkTrunking},
                 {"cdr", false, (Method)&ScriptMethods::scrNop,
                         (Check)&Checks::chkCDR},    
                 {"accept", false, (Method)&Methods::scrAccept,
