@@ -626,6 +626,7 @@ public:
 				bool flashing;
 				bool dialing;
 				bool exiting;
+				bool dtmf;
 				timeout_t duration;
 				char digits[64];
 				char sessionid[16];
@@ -1544,6 +1545,26 @@ public:
 	 */
 	inline void setLogging(std::ostream *output)
 		{logevents = output;};
+
+	/**
+	 * Determine if a span is available.
+	 *
+	 * @param span associated with driver to check.
+	 * @return true if available ports.
+	 */
+	inline bool isSpanable(unsigned span);
+
+	/**
+	 * Deterime if a network destination is reachable through this
+	 * driver, and convert dialing string into network reference.
+	 *
+	 * @param network destination
+	 * @param dialing string
+	 * @param output buffer
+	 * @param size of output buffer
+	 * @return true if reachable
+	 */
+	virtual bool getDestination(const char *target, const char *dial, char *buffer, size_t size);
 };	
 
 /**
@@ -1557,6 +1578,7 @@ class __EXPORT BayonneSpan : public Bayonne, public Keydata
 {
 protected:
 	friend class __EXPORT BayonneSession;
+	friend class __EXPORT BayonneDriver;
 
 	static BayonneSpan *first;
 	static BayonneSpan *last;
@@ -1566,7 +1588,7 @@ protected:
 	unsigned id;
 	BayonneDriver *driver;
 	BayonneSpan *next;
-	timeslot_t timeslot, count;		// timeslots
+	timeslot_t timeslot, count, used;	// timeslots
 
 public:
 	/**
