@@ -848,6 +848,7 @@ bool BayonneSession::stateConnect(Event *event)
 {
 	Event cancel;
 	BayonneSession *s;
+	bool dtmf;
 
         if(enterTone(event))
                 return true;
@@ -860,31 +861,33 @@ bool BayonneSession::stateConnect(Event *event)
 failed:
         case STOP_PARENT:
         case CHILD_FAILED:
-                if(!scriptEvent("dial:failed"))
-                        error("dial-failed");
+                if(!scriptEvent("start:failed"))
+                        error("start-failed");
                 setRunning();
                 return true;
 	case CHILD_INVALID:
-		if(!scriptEvent("dial:invalid"))
-			error("dial-invalid");
+		if(!scriptEvent("start:invalid"))
+			error("start-invalid");
 		setRunning();
 		return true;
         case CHILD_EXPIRED:
-                if(!scriptEvent("dial:noanswer"))
-                        error("dial-noanswer");
+                if(!scriptEvent("start:noanswer"))
+                        error("start-noanswer");
                 setRunning();
                 return true;
         case CHILD_BUSY:
-                if(!scriptEvent("dial:busy"))
-                        error("dial-busy");
+                if(!scriptEvent("start:busy"))
+                        error("start-busy");
                 return true;
 	case CHILD_FAX:
-		if(!scriptEvent("dial:fax"))
-			error("dial-fax");
+		if(!scriptEvent("start:fax"))
+			error("start-fax");
 		return true;
         case PEER_WAITING:
 		s = getSid(state.tone.sessionid);
+		dtmf = state.tone.dtmf;
 		state.timeout = state.tone.duration;
+		state.join.dtmf = dtmf;
 		state.join.dial = NULL;
 		state.join.exit = NULL;
 		state.join.peer = s;
