@@ -211,6 +211,59 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	server->setValue("uri.conf", CONFIG_FILES "/uri.conf");
 }
 
+bool Driver::getDestination(const char *destination, const char *user, char *buf, size_t size)
+{
+	ScriptImage *img = NULL;
+	Registry *r = NULL;
+	const char *cp;
+	char rbuf[65];
+	char *p;
+	bool rtn = true;
+
+	if(!user)
+		return false;
+
+	if(strchr(user, '@') || !destination)
+	{
+		setString(buf, size, user);
+		p = strrchr(buf, ':');
+		if(p && !strcmp(p, ":5060"))
+			*p = 0;
+		return true;
+	}
+
+	img = useImage();
+
+	if(Bayonne::provision_ripple && !strchr(destination, '@'))
+	{
+		snprintf(rbuf, sizeof(rbuf), "sipscr.sip::%s", destination);
+		r = (Registry *)img->getPointer(rbuf);
+		if(r)
+		{
+			rtn = r->active;
+			destination = r->proxy + 4;
+		}
+	}
+	else if(!strchr(destination, '@'))
+	{
+		snprintf(rbuf, sizeof(rbuf), "sipauth.%s", destination);
+		p = strrchr(rbuf, ':');
+		if(p && !strcmp(p, ":5060"))
+			*p = 0;
+		r = (Registry *)img->getPointer(rbuf);
+		if(r)
+			rtn = r->active;
+	}
+
+	cp = strchr(destination, '@');
+	if(cp)
+		destination = ++cp;	
+
+	snprintf(buf, size, "%s@%s", user, destination);
+	endImage(img);
+	return rtn;
+}
+		
 void Driver::startDriver(void)
 {
 	char cbuf[65];
@@ -598,6 +651,10 @@ const char *Driver::registerScript(ScriptImage *img, Line *line)
 		*p = 0;
 	img->setPointer(buf, reg);
 
+	snprintf(buf, sizeof(buf), "sipscr.%s", scr->name);
+	if(!img->getPointer(buf))
+		img->setPointer(buf, reg);
+
 	return "";
 }
 
