@@ -1210,6 +1210,38 @@ error:
 	return true;
 }
 
+bool Methods::scrList(void)
+{
+	const char *cp;
+	char buf[MAX_PATHNAME];
+	Symbol *sym = mapSymbol(getOption(NULL), sizeof(buf));
+	unsigned len = 0;
+		
+	if(!sym)
+	{
+		error("no-symbol");
+		return true;
+	}
+
+	setString(buf, sizeof(buf), keypaths.getLast("datafiles"));
+	len = strlen(buf);
+	cp = getKeyword("prefix");
+	if(!cp)
+		cp = getValue(NULL);
+	while(cp && len < sizeof(buf) - 2)
+	{
+		buf[len++] = '/';
+		setString(buf + len, sizeof(buf) - len, cp);
+		len = strlen(buf);
+		cp = getValue(NULL);
+	}
+
+	Bayonne::clear(sym);
+
+	new ListThread(dynamic_cast<ScriptInterp*>(this), buf, sym);
+	return false;
+}
+
 bool Methods::scrWritepath(void)
 {
 	char buf[MAX_PATHNAME];
