@@ -755,6 +755,7 @@ skipcerr1:
 	
 void Runtime::process(void)
 {
+	const char *argv0 = keyserver.getLast("argv0");
 	FILE *fp;
 	char buf[256];
 	char *cp;
@@ -787,7 +788,7 @@ void Runtime::process(void)
 		fclose(fp);
 	}
 
-	snprintf(buf, sizeof(buf), "%s/bayonne.ctrl", keypaths.getLast("runfiles"));
+	snprintf(buf, sizeof(buf), "%s/%s.ctrl", keypaths.getLast("runfiles"), argv0);
 	remove(buf);
 	mkfifo(buf, 0770);
 	fifo = ::open(buf, O_RDWR);
