@@ -415,11 +415,25 @@ static void banner(void)
 
 int main(int argc, char **argv)
 {
-	char *cp;
+	const char *argv0;
+	const char *cp;
 
 	Script::use_macros = true;
 	Script::use_prefix = true;
 
+#ifdef	WIN32
+	argv0 = "bayonne";
+#else
+	argv0 = strrchr(argv[0], '/');
+
+	if(argv0)
+		++argv0;
+	else
+		argv0 = argv[0];
+#endif
+
+	keyserver.setValue("argv0", argv0);
+
 	if(argc == 2)
 	{
 		cp = argv[1];
@@ -500,6 +514,21 @@ int main(int argc, char **argv)
 	if(Bayonne::provision_check)
 		checking();
 
+	if(stricmp(argv0, "bayonne"))
+	{
+		cp = keygateway.getLast("timeslots");
+		if(cp && *cp)
+			keyswitch.setValue("timeslots", cp);
+
+		cp = keygateway.getLast("trunking");
+		if(cp && *cp)
+			keyswitch.setValue("trunking", cp);
+	
+		cp = keygateway.getLast("binding");
+		if(cp && *cp)
+			keyserver.setValue("binding", cp);
+	}
+		
 	Process::setScheduler(keyengine.getLast("scheduler"));
         Process::setPriority(atoi(keyengine.getLast("priority")));   
 #ifndef WIN32
